from enum import Enum


class GoogleTranslateLanguage (Enum):
    """These are the lanuages that supported with google translate"""
    auto = "auto"
    afrikaans = "afrikaans"
    albanian = "albanian"
    amharic = "amharic"
    arabic = "arabic"
    armenian = "armenian"
    assamese = "assamese"
    aymara = "aymara"
    azerbaijani = "azerbaijani"
    bambara = "bambara"
    basque = "basque"
    belarusian = "belarusian"
    bengali = "bengali"
    bhojpuri = "bhojpuri"
    bosnian = "bosnian"
    bulgarian = "bulgarian"
    catalan = "catalan"
    cebuano = "cebuano"
    chichewa = "chichewa"
    chinese_simplified = "chinese (simplified)"
    chinese_traditional = "chinese (traditional)"
    corsican = "corsican"
    croatian = "croatian"
    czech = "czech"
    danish = "danish"
    dhivehi = "dhivehi"
    dogri = "dogri"
    dutch = "dutch"
    english = "english"
    esperanto = "esperanto"
    estonian = "estonian"
    ewe = "ewe"
    filipino = "filipino"
    finnish = "finnish"
    french = "french"
    frisian = "frisian"
    galician = "galician"
    georgian = "georgian"
    german = "german"
    greek = "greek"
    guarani = "guarani"
    gujarati = "gujarati"
    haitian_creole = "haitian creole"
    hausa = "hausa"
    hawaiian = "hawaiian"
    hebrew = "hebrew"
    hindi = "hindi"
    hmong = "hmong"
    hungarian = "hungarian"
    icelandic = "icelandic"
    igbo = "igbo"
    ilocano = "ilocano"
    indonesian = "indonesian"
    irish = "irish"
    italian = "italian"
    japanese = "japanese"
    javanese = "javanese"
    kannada = "kannada"
    kazakh = "kazakh"
    khmer = "khmer"
    kinyarwanda = "kinyarwanda"
    konkani = "konkani"
    korean = "korean"
    krio = "krio"
    kurdish_kurmanji = "kurdish (kurmanji)"
    kurdish_sorani = "kurdish (sorani)"
    kyrgyz = "kyrgyz"
    lao = "lao"
    latin = "latin"
    latvian = "latvian"
    lingala = "lingala"
    lithuanian = "lithuanian"
    luganda = "luganda"
    luxembourgish = "luxembourgish"
    macedonian = "macedonian"
    maithili = "maithili"
    malagasy = "malagasy"
    malay = "malay"
    malayalam = "malayalam"
    maltese = "maltese"
    maori = "maori"
    marathi = "marathi"
    meiteilon_manipuri = "meiteilon (manipuri)"
    mizo = "mizo"
    mongolian = "mongolian"
    myanmar = "myanmar"
    nepali = "nepali"
    norwegian = "norwegian"
    odia_oriya = "odia (oriya)"
    oromo = "oromo"
    pashto = "pashto"
    persian = "persian"
    polish = "polish"
    portuguese = "portuguese"
    punjabi = "punjabi"
    quechua = "quechua"
    romanian = "romanian"
    russian = "russian"
    samoan = "samoan"
    sanskrit = "sanskrit"
    scots_gaelic = "scots gaelic"
    sepedi = "sepedi"
    serbian = "serbian"
    sesotho = "sesotho"
    shona = "shona"
    sindhi = "sindhi"
    sinhala = "sinhala"
    slovak = "slovak"
    slovenian = "slovenian"
    somali = "somali"
    spanish = "spanish"
    sundanese = "sundanese"
    swahili = "swahili"
    swedish = "swedish"
    tajik = "tajik"
    tamil = "tamil"
    tatar = "tatar"
    telugu = "telugu"
    thai = "thai"
    tigrinya = "tigrinya"
    tsonga = "tsonga"
    turkish = "turkish"
    turkmen = "turkmen"
    twi = "twi"
    ukrainian = "ukrainian"
    urdu = "urdu"
    uyghur = "uyghur"
    uzbek = "uzbek"
    vietnamese = "vietnamese"
    welsh = "welsh"
    xhosa = "xhosa"
    yiddish = "yiddish"
    yoruba = "yoruba"
    zulu = "zulu"