from enum import Enum


class OpusmtLanguage (Enum):
    """
    This class contain all languages supported with OpusMT ML translate.

    Its better with Opusmt to not use `auto`
    """
    auto = "auto"
    af = "af"
    ar = "ar"
    az = "az"
    bn = "bn"
    cs = "cs"
    de = "de"
    en = "en"
    es = "es"
    et = "et"
    fa = "fa"
    fi = "fi"
    fr = "fr"
    gl = "gl"
    gu = "gu"
    he = "he"
    hi = "hi"
    hr = "hr"
    id_language = "id"
    it_language = "it"
    ja = "ja"
    ka = "ka"
    kk = "kk"
    km = "km"
    ko = "ko"
    lt = "lt"
    lv = "lv"
    ml = "ml"
    mn = "mn"
    my = "my"
    ne = "ne"
    nl = "nl"
    pl = "pl"
    ps = "ps"
    pt = "pt"
    ro = "ro"
    ru = "ru"
    si = "si"
    sl = "sl"
    sv = "sv"
    sw = "sw"
    ta = "ta"
    th = "th"
    tl = "tl"
    tr = "tr"
    uk = "uk"
    ur = "ur"
    vi = "vi"
    xh = "xh"
    zh = "zh"